@@ -75,8 +75,6 @@ struct NautilusCanvasItemDetails {
 	cairo_surface_t *rendered_surface;
 	char *editable_text;		/* Text that can be modified by a renaming function */
 	char *additional_text;		/* Text that cannot be modifed, such as file size, etc. */
-	GdkPoint *attach_points;
-	int n_attach_points;
 	
 	/* Size of the text at current font. */
 	int text_dx;
@@ -116,13 +114,9 @@ struct NautilusCanvasItemDetails {
 	
 	guint is_visible : 1;
 
-	GdkRectangle embedded_text_rect;
-	char *embedded_text;
-
 	/* Cached PangoLayouts. Only used if the icon is visible */
 	PangoLayout *editable_text_layout;
 	PangoLayout *additional_text_layout;
-	PangoLayout *embedded_text_layout;
 
 	/* Cached rectangle in canvas coordinates */
 	EelIRect icon_rect;
@@ -212,7 +206,6 @@ nautilus_canvas_item_finalize (GObject *object)
 
 	g_free (details->editable_text);
 	g_free (details->additional_text);
-	g_free (details->attach_points);
 
 	if (details->rendered_surface != NULL) {
 		cairo_surface_destroy (details->rendered_surface);
@@ -226,12 +219,6 @@ nautilus_canvas_item_finalize (GObject *object)
 		g_object_unref (details->additional_text_layout);
 	}
 
-	if (details->embedded_text_layout != NULL) {
-		g_object_unref (details->embedded_text_layout);
-	}
-
-	g_free (details->embedded_text);
-
 	G_OBJECT_CLASS (nautilus_canvas_item_parent_class)->finalize (object);
 }
  
@@ -266,9 +253,6 @@ nautilus_canvas_item_invalidate_label_size (NautilusCanvasItem *item)
 	if (item->details->additional_text_layout != NULL) {
 		pango_layout_context_changed (item->details->additional_text_layout);
 	}
-	if (item->details->embedded_text_layout != NULL) {
-		pango_layout_context_changed (item->details->embedded_text_layout);
-	}
 	nautilus_canvas_item_invalidate_bounds_cache (item);
 	item->details->text_width = -1;
 	item->details->text_height = -1;
@@ -471,52 +455,6 @@ nautilus_canvas_item_set_image (NautilusCanvasItem *item,
 	eel_canvas_item_request_update (EEL_CANVAS_ITEM (item));	
 }
 
-void 
-nautilus_canvas_item_set_attach_points (NautilusCanvasItem *item,
-					GdkPoint *attach_points,
-					int n_attach_points)
-{
-	g_free (item->details->attach_points);
-	item->details->attach_points = NULL;
-	item->details->n_attach_points = 0;
-
-	if (attach_points != NULL && n_attach_points != 0) {
-		item->details->attach_points = g_memdup (attach_points, n_attach_points * sizeof (GdkPoint));
-		item->details->n_attach_points = n_attach_points;
-	}
-	
-	nautilus_canvas_item_invalidate_bounds_cache (item);
-}
-
-void
-nautilus_canvas_item_set_embedded_text_rect (NautilusCanvasItem       *item,
-					     const GdkRectangle           *text_rect)
-{
-	item->details->embedded_text_rect = *text_rect;
-
-	nautilus_canvas_item_invalidate_bounds_cache (item);
-	eel_canvas_item_request_update (EEL_CANVAS_ITEM (item));
-}
-
-void
-nautilus_canvas_item_set_embedded_text (NautilusCanvasItem       *item,
-					const char                   *text)
-{
-	g_free (item->details->embedded_text);
-	item->details->embedded_text = g_strdup (text);
-
-	if (item->details->embedded_text_layout != NULL) {
-		if (text != NULL) {
-			pango_layout_set_text (item->details->embedded_text_layout, text, -1);
-		} else {
-			pango_layout_set_text (item->details->embedded_text_layout, "", -1);
-		}
-	}
-
-	eel_canvas_item_request_update (EEL_CANVAS_ITEM (item));
-}
-
-
 /* Recomputes the bounding box of a canvas item.
  * This is a generic implementation that could be used for any canvas item
  * class, it has no assumptions about how the item is used.
@@ -1103,14 +1041,8 @@ nautilus_canvas_item_invalidate_label (NautilusCanvasItem     *item)
 		g_object_unref (item->details->additional_text_layout);
 		item->details->additional_text_layout = NULL;
 	}
-
-	if (item->details->embedded_text_layout) {
-		g_object_unref (item->details->embedded_text_layout);
-		item->details->embedded_text_layout = NULL;
-	}
 }
 
-
 static GdkPixbuf *
 get_knob_pixbuf (void)
 {
@@ -1260,63 +1192,6 @@ map_surface (NautilusCanvasItem *canvas_item)
 	return canvas_item->details->rendered_surface;
 }
 
-static void
-draw_embedded_text (NautilusCanvasItem *item,
-                    cairo_t *cr,
-		    int x, int y)
-{
-	PangoLayout *layout;
-	PangoContext *context;
-	PangoFontDescription *desc;
-	GtkWidget *widget;
-	GtkStyleContext *style_context;
-
-	if (item->details->embedded_text == NULL ||
-	    item->details->embedded_text_rect.width == 0 ||
-	    item->details->embedded_text_rect.height == 0) {
-		return;
-	}
-
-	widget = GTK_WIDGET (EEL_CANVAS_ITEM (item)->canvas);
-
-	if (item->details->embedded_text_layout != NULL) {
-		layout = g_object_ref (item->details->embedded_text_layout);
-	} else {
-		context = gtk_widget_get_pango_context (widget);
-		layout = pango_layout_new (context);
-		pango_layout_set_text (layout, item->details->embedded_text, -1);
-		
-		desc = pango_font_description_from_string ("monospace 6");
-		pango_layout_set_font_description (layout, desc);
-		pango_font_description_free (desc);
-
-		if (item->details->is_visible) {
-			item->details->embedded_text_layout = g_object_ref (layout);
-		}
-	}
-
-	style_context = gtk_widget_get_style_context (widget);
-	gtk_style_context_save (style_context);
-	gtk_style_context_add_class (style_context, "icon-embedded-text");
-
-	cairo_save (cr);
-
-	cairo_rectangle (cr,
-			 x + item->details->embedded_text_rect.x,
-			 y + item->details->embedded_text_rect.y,
-			 item->details->embedded_text_rect.width,
-			 item->details->embedded_text_rect.height);
-	cairo_clip (cr);
-
-	gtk_render_layout (style_context, cr,
-			   x + item->details->embedded_text_rect.x,
-			   y + item->details->embedded_text_rect.y,
-			   layout);
-
-	gtk_style_context_restore (style_context);
-	cairo_restore (cr);
-}
-
 cairo_surface_t *
 nautilus_canvas_item_get_drag_surface (NautilusCanvasItem *item)
 {
@@ -1371,8 +1246,6 @@ nautilus_canvas_item_get_drag_surface (NautilusCanvasItem *item)
 	icon_rect.x1 = item_offset_x + pix_width;
 	icon_rect.y1 = item_offset_y + pix_height;
 
-	draw_embedded_text (item, cr,
-			    item_offset_x, item_offset_y);
 	draw_label_text (item, cr, icon_rect);
 	cairo_destroy (cr);
 
@@ -1415,8 +1288,6 @@ nautilus_canvas_item_draw (EelCanvasItem *item,
 				 icon_rect.x0, icon_rect.y0);
 	cairo_surface_destroy (temp_surface);
 
-	draw_embedded_text (canvas_item, cr, icon_rect.x0, icon_rect.y0);
-	
 	/* Draw stretching handles (if necessary). */
 	draw_stretch_handles (canvas_item, cr, &icon_rect);
 	
