@@ -429,17 +429,6 @@ bind_builder_bool (GtkBuilder *builder,
 			 "active", G_SETTINGS_BIND_DEFAULT);
 }
 
-static void
-bind_builder_bool_oneway (GtkBuilder *builder,
-			  GSettings *settings,
-			  const char *widget_name,
-			  const char *prefs)
-{
-	g_settings_bind (settings, prefs,
-			 gtk_builder_get_object (builder, widget_name),
-			 "active", G_SETTINGS_BIND_SET);
-}
-
 static gboolean
 enum_get_mapping (GValue             *value,
 		  GVariant           *variant,
@@ -597,6 +586,14 @@ bind_builder_radio (GtkBuilder *builder,
 	}
 }
 
+static void
+set_gtk_filechooser_sort_first (GObject *object,
+				GParamSpec *pspec)
+{
+	g_settings_set_boolean (gtk_filechooser_preferences,
+				NAUTILUS_PREFERENCES_SORT_DIRECTORIES_FIRST,
+				gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (object)));
+}
 
 static  void
 nautilus_file_management_properties_dialog_setup (GtkBuilder *builder, GtkWindow *window)
@@ -618,9 +615,9 @@ nautilus_file_management_properties_dialog_setup (GtkBuilder *builder, GtkWindow
 	bind_builder_bool (builder, nautilus_preferences,
 			   NAUTILUS_FILE_MANAGEMENT_PROPERTIES_FOLDERS_FIRST_WIDGET,
 			   NAUTILUS_PREFERENCES_SORT_DIRECTORIES_FIRST);
-	bind_builder_bool_oneway (builder, gtk_filechooser_preferences,
-				  NAUTILUS_FILE_MANAGEMENT_PROPERTIES_FOLDERS_FIRST_WIDGET,
-			   NAUTILUS_PREFERENCES_SORT_DIRECTORIES_FIRST);
+	g_signal_connect (gtk_builder_get_object (builder, NAUTILUS_FILE_MANAGEMENT_PROPERTIES_FOLDERS_FIRST_WIDGET),
+                          "notify::active",
+                          G_CALLBACK (set_gtk_filechooser_sort_first), NULL);
 
 	bind_builder_bool (builder, nautilus_preferences,
 			   NAUTILUS_FILE_MANAGEMENT_PROPERTIES_TRASH_CONFIRM_WIDGET,
